#======================================================================
# This file contains the typespecific values of the metrics, scoring
# criteria, scores and weight of each member of the hmmfi family.
#
# This information is the 'essence' of the HMMFI.
#
# The argument and their values are complied in list form.
#
#
#
# metrics  A számításhoz használandó metrikák neveinek karaktervektora.
#          A neveknek meg kell egyezni az adattáblázat megfelelő oszlopainak neveivel.
#
# SC   Scoring Criteria. Az a kvantilis felosztás, aminek a függvényében
#      a minta pontszámot (score) kap.
#      Lista objektum, az elemeinek neve az egyes metrikák neve, melyek
#      sorrendje meg kell egyezzen a 'metrics'-ben levő sorrenddel.
#      Az egyes listaelmek vektorok, melyek a cut függvénynek szolgálnak
#     'bresaks' argumentumként.
#
# scores  Az egyes metrikák után adható pontszámok.
#         Lista objektum, az elemeinek neve az egyes metrikák neve, melyek
#         sorrendje meg kell egyezzen a 'metrics'-ben levő sorrenddel.
#         Az egyes listaelmek vektorok, és sorrendben tartalmazzák azokat
#         a pontértékeket, amiket a minta kaphat az adott metrikaértéke függvényében
#         az SC felosztás szerint.
#
# weights   Súlyok. Az egyes metrikák súlyait tartalmazó listaobjektum.
#           Lista objektum, az elemeinek neve az egyes metrikák neve, melyek
#           sorrendje meg kell egyezzen a 'metrics'-ben levő sorrenddel.
#           Az egyes listaelemek konstansok.
#======================================================================



#======================================================================
# Metrics:
#*********
METRICS <- list(
    # typ1 SMS:
    typ1 = c("OMN.ra",
             "BEN.ra",
             "OMN.sn",
             "PEL.sn",
             "PEL.rsn",
             "BEN.rsn",
             "LIT.rsn",
             "NN.ra",
             "CSpecpool"),
    # typ2 HLS:
    typ2 = c("RHE.ra",
             "EU.ra",
             "SPEC.ra",
             "MET.sn",
             "PHY_LIT.sn",
             "RHE.sn",
             "LIT.rsn",
             "SPEC.rsn",
             "NN.rsn",
             "NN.ra",
             "CSpecpool"),
    # typ3 HLR:
    typ3 = c("LIT.ra",
             "TOL.ra",
             "RHE.sn",
             "GEN.sn",
             "TOL.sn",
             "NN.sn",
             "INV_DET.rsn",
             "MET.rsn",
             "NN.ra",
             "CSpecpool"),
    # typ4 LLS:
    typ4 = c("MET.ra",
             "PHY.ra",
             "RHE.ra",
             "OMN.sn",
             "MET.sn",
             "PHY.rsn",
             "TOL.rsn",
             "NN.rsn",
             "NN.ra",
             "CSpecpool"),
    # typ5 LLR:
    typ5 = c("PEL.ra",
             "PEL.sn",
             "BEN.sn",
             "OMN.rsn",
             "PIS.rsn",
             "BEN.rsn",
             "PHY_LIT.rsn",
             "RHE.rsn",
             "SPEC.rsn",
             "NN.ra",
             "CSpecpool"),
    # typ6 DANUBE:
    typ6 = c("LIT.ra", # typ3
             "TOL.ra",
             "RHE.sn",
             "GEN.sn",
             "TOL.sn",
             "NN.sn",
             "INV_DET.rsn",
             "MET.rsn", # typ3
             "PEL.ra", # typ5
             "PEL.sn",
             "BEN.sn",
             "OMN.rsn",
             "PIS.rsn",
             "BEN.rsn",
             "PHY_LIT.rsn",
             "RHE.rsn",
             "SPEC.rsn",
             "NN.ra",
             "CSpecpool") ) # typ5
#METRICS
#======================================================================



#======================================================================
# Scoring Criteria (SC - scrit):
#*******************************
SCRIT <- list(
    # typ1 SMS:
    typ1 = list("OMN.ra"      =c(0, 0.60, 1),
                "BEN.ra"      =c(0, 0.15, 1),
                "OMN.sn"      =c(0, 2, Inf),
                "PEL.sn"      =c(0, 1, Inf),
                "PEL.rsn"     =c(0, 0.30, 1),
                "BEN.rsn"     =c(0, 0.50, 1),
                "LIT.rsn"     =c(0, 0.75, 1),
                "NN.ra"       =c(0, 0.05, 0.50, 1),
                "CSpecpool"   =c(0, 0.25, 0.50, 0.75, 1)),
    # typ2 HLS:
    typ2 = list("RHE.ra"      =c(0, 0.60, 1),
                "EU.ra"       =c(0, 0.17, 1),
                "SPEC.ra"     =c(0, 0.50, 1),
                "MET.sn"      =c(0, 2, Inf),
                "PHY_LIT.sn"  =c(0, 2, Inf),
                "RHE.sn"      =c(0, 3, Inf),
                "LIT.rsn"     =c(0, 0.50, 1),
                "SPEC.rsn"    =c(0, 0.60, 1),
                "NN.rsn"      =c(0, 0.20, 1),
                "NN.ra"       =c(0, 0.05, 0.50, 1),
                "CSpecpool"   =c(0, 0.25, 0.50, 0.75, 1)),
    # typ3 HLR:
    typ3 = list("LIT.ra"      =c(0, 0.20, 1),
                "TOL.ra"      =c(0, 0.11, 1),
                "RHE.sn"      =c(0, 6, Inf),
                "GEN.sn"      =c(0, 3, Inf),
                "TOL.sn"      =c(0, 3, Inf),
                "NN.sn"       =c(0, 1, Inf),
                "INV_DET.rsn" =c(0, 0.33, 1),
                "MET.rsn"     =c(0, 0.16, 1),
                "NN.ra"       =c(0, 0.05, 0.50, 1),
                "CSpecpool"   =c(0, 0.25, 0.50, 0.75, 1)),
    # typ4 LLS:
    typ4 = list("MET.ra"      =c(0, 0.35, 1),
                "PHY.ra"      =c(0, 0.40, 1),
                "RHE.ra"      =c(0, 0.20, 1),
                "OMN.sn"      =c(0, 2, Inf),
                "MET.sn"      =c(0, 3, Inf),
                "PHY.rsn"     =c(0, 0.60, 1),
                "TOL.rsn"     =c(0, 0.50, 1),
                "NN.rsn"      =c(0, 0.25, 1),
                "NN.ra"       =c(0, 0.05, 0.50, 1),
                "CSpecpool"   =c(0, 0.25, 0.50, 0.75, 1)),   #"CSpecpool4"  =c(0, 0.25, 0.50, 0.70, 1))
    # typ5 LLR:
    typ5 = list("PEL.ra"      =c(0, 0.22, 0.80, 1),
                "PEL.sn"      =c(0, 4, Inf),
                "BEN.sn"      =c(0, 7, Inf),
                "OMN.rsn"     =c(0, 0.44, 0.78, 1),
                "PIS.rsn"     =c(0, 0.065, 0.25, 1),
                "BEN.rsn"     =c(0, 0.43, 1),
                "PHY_LIT.rsn" =c(0, 0.36, 1),
                "RHE.rsn"     =c(0, 0.25, 0.44, 1),
                "SPEC.rsn"    =c(0, 0.25, 0.50, 1),
                "NN.ra"       =c(0, 0.05, 0.50, 1),
                "CSpecpool"   =c(0, 0.25, 0.50, 0.75, 1)),
    # typ6 DANUBE:
    typ6 = list("LIT.ra"      =c(0, 0.20, 1),  # typ3
                "TOL.ra"      =c(0, 0.11, 1),
                "RHE.sn"      =c(0, 6, Inf),
                "GEN.sn"      =c(0, 3, Inf),
                "TOL.sn"      =c(0, 3, Inf),
                "NN.sn"       =c(0, 1, Inf),
                "INV_DET.rsn" =c(0, 0.33, 1),
                "MET.rsn"     =c(0, 0.16, 1), # typ3
                "PEL.ra"      =c(0, 0.22, 0.80, 1), #typ5
                "PEL.sn"      =c(0, 4, Inf),
                "BEN.sn"      =c(0, 7, Inf),
                "OMN.rsn"     =c(0, 0.44, 0.78, 1),
                "PIS.rsn"     =c(0, 0.065, 0.25, 1),
                "BEN.rsn"     =c(0, 0.43, 1),
                "PHY_LIT.rsn" =c(0, 0.36, 1),
                "RHE.rsn"     =c(0, 0.25, 0.44, 1),
                "SPEC.rsn"    =c(0, 0.25, 0.50, 1),
                "NN.ra"       =c(0, 0.05, 0.50, 1),
                "CSpecpool"   =c(0, 0.25, 0.50, 0.75, 1)) )  # typ5
#SCRIT
#======================================================================





#======================================================================
# Scores (scores):
#*****************
SCORES <- list(
    # typ1 SMS:
    typ1 = list("OMN.ra"      =c(1,2),
                "BEN.ra"      =c(2,1),
                "OMN.sn"      =c(2,1),
                "PEL.sn"      =c(1,2),
                "PEL.rsn"     =c(1,2),
                "BEN.rsn"     =c(2,1),
                "LIT.rsn"     =c(1,2),
                "NN.ra"       =c(3,2,1),
                "CSpecpool"   =c(1,2,3,4)),
    # typ2 HLS:
    typ2 = list("RHE.ra"      =c(1,2),
                "EU.ra"       =c(2,1),
                "SPEC.ra"     =c(1,2),
                "MET.sn"      =c(2,1),
                "PHY_LIT.sn"  =c(2,1),
                "RHE.sn"      =c(1,2),
                "LIT.rsn"     =c(1,2),
                "SPEC.rsn"    =c(1,2),
                "NN.rsn"      =c(2,1),
                "NN.ra"       =c(3,2,1),
                "CSpecpool"   =c(1,2,3,4)),
    # typ3 HLR:
    typ3 = list("LIT.ra"      =c(1,2),
                "TOL.ra"      =c(2,1),
                "RHE.sn"      =c(1,2),
                "GEN.sn"      =c(2,1),
                "TOL.sn"      =c(2,1),
                "NN.sn"       =c(2,1),
                "INV_DET.rsn" =c(1,2),
                "MET.rsn"     =c(2,1),
                "NN.ra"       =c(3,2,1),
                "CSpecpool"   =c(1,2,3,4)),
    # typ4 LLS:
    typ4 = list("MET.ra"      =c(1,2),
                "PHY.ra"      =c(2,1),
                "RHE.ra"      =c(1,2),
                "OMN.sn"      =c(1,2),
                "MET.sn"      =c(1,2),
                "PHY.rsn"     =c(2,1),
                "TOL.rsn"     =c(2,1),
                "NN.rsn"      =c(2,1),
                "NN.ra"       =c(3,2,1),
                "CSpecpool"   =c(1,2,3,4)),
    # typ5 LLR:
    typ5 = list("PEL.ra"      =c(1,2,3),
                "PEL.sn"      =c(1,2),
                "BEN.sn"      =c(1,2),
                "OMN.rsn"     =c(3,2,1),
                "PIS.rsn"     =c(1,2,3),
                "BEN.rsn"     =c(1,2),
                "PHY_LIT.rsn" =c(2,1),
                "RHE.rsn"     =c(1,2,3),
                "SPEC.rsn"    =c(1,2,3),
                "NN.ra"       =c(3,2,1),
                "CSpecpool"   =c(1,2,3,4)),
    # typ6 DANUBE
    typ6 = list("LIT.ra"      =c(1,2),  # typ3
                "TOL.ra"      =c(2,1),
                "RHE.sn"      =c(1,2),
                "GEN.sn"      =c(2,1),
                "TOL.sn"      =c(2,1),
                "NN.sn"       =c(2,1),
                "INV_DET.rsn" =c(1,2),
                "MET.rsn"     =c(2,1), # typ3
                "PEL.ra"      =c(1,2,3), # typ5
                "PEL.sn"      =c(1,2),
                "BEN.sn"      =c(1,2),
                "OMN.rsn"     =c(3,2,1),
                "PIS.rsn"     =c(1,2,3),
                "BEN.rsn"     =c(1,2),
                "PHY_LIT.rsn" =c(2,1),
                "RHE.rsn"     =c(1,2,3),
                "SPEC.rsn"    =c(1,2,3),
                "NN.ra"       =c(3,2,1),
                "CSpecpool"   =c(1,2,3,4)) )  # typ5
#SCORES
#======================================================================



#======================================================================
# Weights (weights):
#*******************
WEIGHTS <- list(
    # typ1 SMS:
    typ1 = list("OMN.ra"      =1,
                "BEN.ra"      =2,
                "OMN.sn"      =1,
                "PEL.sn"      =1,
                "PEL.rsn"     =1,
                "BEN.rsn"     =1,
                "LIT.rsn"     =3,
                "NN.ra"       =3,
                "CSpecpool"   =4),
    # typ2 HLS:
    typ2 = list("RHE.ra"      =1,
                "EU.ra"       =1,
                "SPEC.ra"     =2,
                "MET.sn"      =1,
                "PHY_LIT.sn"  =1,
                "RHE.sn"      =1,
                "LIT.rsn"     =1,
                "SPEC.rsn"    =1,
                "NN.rsn"      =2,
                "NN.ra"       =3,
                "CSpecpool"   =4),
    # typ3 HLR:
    typ3 = list("LIT.ra"      =1,
                "TOL.ra"      =1,
                "RHE.sn"      =1,
                "GEN.sn"      =1,
                "TOL.sn"      =1,
                "NN.sn"       =2,
                "INV_DET.rsn" =1,
                "MET.rsn"     =1,
                "NN.ra"       =3,
                "CSpecpool"   =4),
    # typ4 LLS:
    typ4 = list("MET.ra"      =1,
                "PHY.ra"      =1,
                "RHE.ra"      =1,
                "OMN.sn"      =1,
                "MET.sn"      =2,
                "PHY.rsn"     =1,
                "TOL.rsn"     =2,
                "NN.rsn"      =2,
                "NN.ra"       =3,
                "CSpecpool"   =4),
    # typ5 LLR:
    typ5 = list("PEL.ra"      =2,
                "PEL.sn"      =1,
                "BEN.sn"      =1,
                "OMN.rsn"     =2,
                "PIS.rsn"     =1,
                "BEN.rsn"     =1,
                "PHY_LIT.rsn" =1,
                "RHE.rsn"     =1,
                "SPEC.rsn"    =1,
                "NN.ra"       =3,
                "CSpecpool"   =4),
    # typ6 DANUBE:
    typ6 = list("LIT.ra"      =1,  # typ3
                "TOL.ra"      =1,
                "RHE.sn"      =1,
                "GEN.sn"      =1,
                "TOL.sn"      =1,
                "NN.sn"       =2,
                "INV_DET.rsn" =1,
                "MET.rsn"     =1, # typ3
                "PEL.ra"      =2, # typ5
                "PEL.sn"      =1,
                "BEN.sn"      =1,
                "OMN.rsn"     =2,
                "PIS.rsn"     =1,
                "BEN.rsn"     =1,
                "PHY_LIT.rsn" =1,
                "RHE.rsn"     =1,
                "SPEC.rsn"    =1,
                "NN.ra"       =3,
                "CSpecpool"   =4*2.5) )  # typ5
#WEIGHTS
#======================================================================

# *** End of file ***
